% Copyright (C) 2008 Medical College of Wisconsin.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the Medical College of Wisconsin. For details
% please see User License Agreement.

clear all;

% Succinyl-CoA Synthetase reaction (EC 6.2.1.4)

%% Setting up and running Example 1
% (1.) Setting parameter values (no buffering)
B_X   = 0;      % Additional proton buffering capacity
K_BX = 1e-7;    % Dissociation constant of additional proton buffer
par(1) = 0.05;  % Vmf_SCS
T = 25;         % Temperature

% (2.) Setting initial values
xo(1) = 3e-3;       % SuccinylcoA (M)
xo(2) = 5e-4;       % GDP (M)
xo(3) = 1e-3;       % Pi (M)
xo(4) = 1e-3;       % Succinate (M)
xo(5) = 1e-3;       % GTP (M)
xo(6) = 1e-3;       % COAS (M)
xo(7) = 1e-7;       % [H] (M)
xo(8) = 1e-3;       % [Mg] (M)
xo(9) = 150e-3;     % [K] (M)

% (3.) Running for 15-second time course
[t,x] = ode15s(@SCS,[0 15],xo,[],T,B_X,K_BX,par);
% (4.) Plotting results
figure(1); p = plot(t,x(:,1)*1e3,'k-',t,x(:,4)*1e3,'k:');
set(p,'linewidth',1.5);
text(1,2.75,'SuccinylcoA','Fontsize',14);
text(1,1.25,'Succinate','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(2); p = plot(t,x(:,2)*1e3,'k-',t,x(:,5)*1e3,'k:');
set(p,'linewidth',1.5);
text(5,1,'GTP','Fontsize',14);
text(5,.5,'GDP','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(3); p = plot(t,-log10(x(:,7)),'k-','LineWidth',1.5);
ylabel('pH','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(4); p = plot(t,x(:,6)*1e3,'k-');
set(p,'linewidth',1.5);
text(5,1.07,'COAS','Fontsize',14);
%text(5,.1,'GDP','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);

Table = array2table([t,x],'variableNames',{'Time','BISEN_SucCoA','BISEN_GDP','BISEN_Pi','BISEN_Suc','GTP','CoA','BISEN_H','BISEN_Mg','BISEN_K'});
S1 = 'SCSBisenOutput';
S2 = '.csv';
filename1 = strcat(S1);  % Append runtime to filename
filename = strcat(filename1,S2);
%filename = 'SCSisenOutput.csv';
writetable(Table,filename);
%%
